INTRODUCTION
============

This project is a suite of tools designed to ease the process of developing
assembly language apps for the TI-83 Plus series of calculators.  Currently,
it contains the following tools:

- zmake (inspired by qmake of qt), which produces a Makefile that describes
  the build process for a TI-83 Plus assembly language application, and

- zabc (Z80 Application Boilerplate Compiler), which generates an assembly
  language file that can be assembled into an application.

It also includes some assembly language libraries and a sample application to
build.


INSTALLATION AND DEPENDENCIES
=============================

Currently, this project is only supported on Unix-like operating systems.
It is a Python project located on PyPI, and can therefore be installed by
running some variation of ``pip install zproj`` (perhaps with root access).

The following dependencies are required to use this project:

- Python 3.  The tools are written in Python, and have not been designed with
  Python 2 in mind.

- peeker.  This is a small Python package used by the tools included in this
  project.  

- GNU make or equivalent.  This program must be installed in order to use
  the Makefile generated by zmake.

- spasm.  This is the assembler currently used and supported by the project,
  and must therefore be installed to perform builds.

- rabbitsign.  TI-83 Plus applications must be digitally signed in order to
  be loaded onto calculators, and rabbitsign is the application signer
  currently supported by this project.


EXAMPLE
=======

This project ships with an example "Hello World" application that can be built
using the tools contained in this project.  After installing the project and the
above dependencies, changing directories into ``examples/hello`` and running
``zmake`` followed by ``make`` should build a .8xk file that can be loaded onto
an actual or simulated TI-83 Plus series calculator.
